..
    This file is part of COUNTER-Robots.
    Copyright (C) 2018 CERN.

    COUNTER-Robots is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

Authors
=======

Library for COUNTER-compliant detection of machines and robots.

- Alexander Ioannidis
- Chiara Bigarella
- Lars Holm Nielsen
